@@ -1,11 +1,9 @@
-#line 1 "inc/Test/Base.pm - /Users/ingy/local/lib/perl5/site_perl/5.8.6/Test/Base.pm"
-# TODO:
-#
+#line 1
 package Test::Base;
 use 5.006001;
 use Spiffy 0.30 -Base;
 use Spiffy ':XXX';
-our $VERSION = '0.50';
+our $VERSION = '0.60';
 
 my @test_more_exports;
 BEGIN {
@@ -14,9 +12,11 @@ BEGIN {
         skip todo_skip pass fail
         eq_array eq_hash eq_set
         plan can_ok isa_ok diag
+        use_ok
         $TODO
     );
 }
+
 use Test::More import => \@test_more_exports;
 use Carp;
 
@@ -27,8 +27,9 @@ our @EXPORT = (@test_more_exports, qw(
     delimiters spec_file spec_string 
     filters filters_delay filter_arguments
     run run_compare run_is run_is_deeply run_like run_unlike 
+    skip_all_unless_require is_deep run_is_deep
     WWW XXX YYY ZZZ
-    tie_output
+    tie_output no_diag_on_only
 
     find_my_self default_object
 
@@ -49,6 +50,7 @@ field block_delim =>
 field data_delim =>
       -init => '$self->data_delim_default';
 field _filters_delay => 0;
+field _no_diag_on_only => 0;
 
 field block_delim_default => '===';
 field data_delim_default => '---';
@@ -76,11 +78,18 @@ sub import() {
 #           unless $default_class->isa($class);
 #     }
 
-    if (@_ > 1 and not grep /^-base$/i, @_) {
-        my @args = @_;
-        shift @args;
-        Test::More->import(import => \@test_more_exports, @args);
-    }
+    unless (grep /^-base$/i, @_) {
+        my @args;
+        for (my $ii = 1; $ii <= $#_; ++$ii) {
+            if ($_[$ii] eq '-package') {
+                ++$ii;
+            } else {
+                push @args, $_[$ii];
+            }
+        }
+        Test::More->import(import => \@test_more_exports, @args)
+            if @args;
+     }
     
     _strict_warnings();
     goto &Spiffy::import;
@@ -181,6 +190,11 @@ sub filters_delay() {
     $self->_filters_delay(defined $_[0] ? shift : 1);
 }
 
+sub no_diag_on_only() {
+    (my ($self), @_) = find_my_self(@_);
+    $self->_no_diag_on_only(defined $_[0] ? shift : 1);
+}
+
 sub delimiters() {
     (my ($self), @_) = find_my_self(@_);
     $self->check_late;
@@ -355,6 +369,34 @@ sub run_unlike() {
     }
 }
 
+sub skip_all_unless_require() {
+    (my ($self), @_) = find_my_self(@_);
+    my $module = shift;
+    eval "require $module; 1"
+        or Test::More::plan(
+            skip_all => "$module failed to load"
+        );
+}
+
+sub is_deep() {
+    (my ($self), @_) = find_my_self(@_);
+    require Test::Deep;
+    Test::Deep::cmp_deeply(@_);
+}
+
+sub run_is_deep() {
+    (my ($self), @_) = find_my_self(@_);
+    $self->_assert_plan;
+    my ($x, $y) = $self->_section_names(@_);
+    for my $block (@{$self->block_list}) {
+        next unless exists($block->{$x}) and exists($block->{$y});
+        $block->run_filters unless $block->is_filtered;
+        is_deep($block->$x, $block->$y, 
+           $block->name ? $block->name : ()
+          );
+    }
+}
+
 sub _pre_eval {
     my $spec = shift;
     return $spec unless $spec =~
@@ -385,6 +427,8 @@ sub _choose_blocks {
     for my $hunk (@_) {
         my $block = $self->_make_block($hunk);
         if (exists $block->{ONLY}) {
+            diag "I found ONLY: maybe you're debugging?"
+                unless $self->_no_diag_on_only;
             return [$block];
         }
         next if exists $block->{SKIP};
@@ -490,7 +534,7 @@ sub _strict_warnings() {
 sub tie_output() {
     my $handle = shift;
     die "No buffer to tie" unless @_;
-    tie $handle, 'Test::Base::Handle', $_[0];
+    tie *$handle, 'Test::Base::Handle', $_[0];
 }
 
 sub no_diff {
@@ -568,11 +612,17 @@ sub run_filters {
             my $function = "main::$filter";
             no strict 'refs';
             if (defined &$function) {
-                $_ = join '', @value;
+                local $_ =
+                    (@value == 1 and not defined($value[0])) ? undef :
+                        join '', @value;
+                my $old = $_;
                 @value = &$function(@value);
                 if (not(@value) or 
-                    @value == 1 and $value[0] =~ /\A(\d+|)\z/
+                    @value == 1 and defined($value[0]) and $value[0] =~ /\A(\d+|)\z/
                 ) {
+                    if ($value[0] && $_ eq $old) {
+                        Test::Base::diag("Filters returning numbers are supposed to do munging \$_: your filter '$function' apparently doesn't.");
+                    }
                     @value = ($_);
                 }
             }
@@ -627,4 +677,6 @@ sub _get_filters {
 
 __DATA__
 
-#line 1289
+=encoding utf8
+
+#line 1374
