@@ -6,7 +6,7 @@ compiled Jemplate templates.
 
 AUTHOR - Ingy döt Net <ingy@cpan.org>
 
-Copyright 2006-2014 Ingy döt Net.
+Copyright 2006,2008 Ingy döt Net.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -29,6 +29,11 @@ Jemplate.process = function() {
     return jemplate.process.apply(jemplate, arguments);
 }
 
+// commonjs export style
+if (typeof(exports) == "object") {
+    exports.Jemplate = Jemplate;
+}
+
 ;(function(){
 
 if (! Jemplate.templateMap)
@@ -1907,7 +1912,7 @@ Jemplate.JSON = {
    Template Toolkit. Any changes made to this file will be lost the next
    time the templates are compiled.
 
-   Copyright 2006-2014 - Ingy döt Net - All rights reserved.
+   Copyright 2006-2008 - Ingy döt Net - All rights reserved.
 */
 
 var Jemplate;
